@@ -26,7 +26,7 @@ import publication
 import aws_cdk.core
 import constructs
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-inspector", "1.33.1", __name__, "aws-inspector@1.33.1.jsii.tgz")
+from ._jsii import *
 
 
 @jsii.implements(aws_cdk.core.IInspectable)
@@ -62,7 +62,7 @@ class CfnAssessmentTarget(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsi
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
+    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -85,7 +85,7 @@ class CfnAssessmentTarget(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsi
 
     @builtins.property
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
     @builtins.property
@@ -119,7 +119,7 @@ class CfnAssessmentTarget(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsi
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-inspector.CfnAssessmentTargetProps", jsii_struct_bases=[], name_mapping={'assessment_target_name': 'assessmentTargetName', 'resource_group_arn': 'resourceGroupArn'})
 class CfnAssessmentTargetProps():
-    def __init__(self, *, assessment_target_name: typing.Optional[str]=None, resource_group_arn: typing.Optional[str]=None):
+    def __init__(self, *, assessment_target_name: typing.Optional[str]=None, resource_group_arn: typing.Optional[str]=None) -> None:
         """Properties for defining a ``AWS::Inspector::AssessmentTarget``.
 
         :param assessment_target_name: ``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
@@ -197,7 +197,7 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
+    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -220,7 +220,7 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
 
     @builtins.property
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
     @builtins.property
@@ -296,7 +296,7 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-inspector.CfnAssessmentTemplateProps", jsii_struct_bases=[], name_mapping={'assessment_target_arn': 'assessmentTargetArn', 'duration_in_seconds': 'durationInSeconds', 'rules_package_arns': 'rulesPackageArns', 'assessment_template_name': 'assessmentTemplateName', 'user_attributes_for_findings': 'userAttributesForFindings'})
 class CfnAssessmentTemplateProps():
-    def __init__(self, *, assessment_target_arn: str, duration_in_seconds: jsii.Number, rules_package_arns: typing.List[str], assessment_template_name: typing.Optional[str]=None, user_attributes_for_findings: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]]=None):
+    def __init__(self, *, assessment_target_arn: str, duration_in_seconds: jsii.Number, rules_package_arns: typing.List[str], assessment_template_name: typing.Optional[str]=None, user_attributes_for_findings: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional[typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]]=None) -> None:
         """Properties for defining a ``AWS::Inspector::AssessmentTemplate``.
 
         :param assessment_target_arn: ``AWS::Inspector::AssessmentTemplate.AssessmentTargetArn``.
@@ -403,7 +403,7 @@ class CfnResourceGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_t
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
+    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -426,7 +426,7 @@ class CfnResourceGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_t
 
     @builtins.property
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
     @builtins.property
@@ -446,7 +446,7 @@ class CfnResourceGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_t
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-inspector.CfnResourceGroupProps", jsii_struct_bases=[], name_mapping={'resource_group_tags': 'resourceGroupTags'})
 class CfnResourceGroupProps():
-    def __init__(self, *, resource_group_tags: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]):
+    def __init__(self, *, resource_group_tags: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]) -> None:
         """Properties for defining a ``AWS::Inspector::ResourceGroup``.
 
         :param resource_group_tags: ``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
@@ -477,6 +477,13 @@ class CfnResourceGroupProps():
         return 'CfnResourceGroupProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
-__all__ = ["CfnAssessmentTarget", "CfnAssessmentTargetProps", "CfnAssessmentTemplate", "CfnAssessmentTemplateProps", "CfnResourceGroup", "CfnResourceGroupProps", "__jsii_assembly__"]
+__all__ = [
+    "CfnAssessmentTarget",
+    "CfnAssessmentTargetProps",
+    "CfnAssessmentTemplate",
+    "CfnAssessmentTemplateProps",
+    "CfnResourceGroup",
+    "CfnResourceGroupProps",
+]
 
 publication.publish()
